@@ -35,7 +35,8 @@ class LM:
                  num_gpus: int = None,
                  torch_dtype=None,
                  device_map: str = None,
-                 low_cpu_mem_usage: bool = False):
+                 low_cpu_mem_usage: bool = False,
+                 hf_cache_dir: str = None):
         """ Language Model.
 
         @param model: Model alias or path to local model file.
@@ -46,18 +47,18 @@ class LM:
         logging.info(f'Loading Model: `{model}`')
 
         # load model
-        local_files_only = not internet_connection()
-        self.tokenizer = transformers.AutoTokenizer.from_pretrained(
-            model, local_files_only=local_files_only, use_auth_token=use_auth_token)
-        self.config = transformers.AutoConfig.from_pretrained(
-            model, local_files_only=local_files_only, use_auth_token=use_auth_token)
+        params = {"local_files_only": not internet_connection(), "use_auth_token": use_auth_token}
+        if hf_cache_dir is not None:
+            params["cache_dir"] = hf_cache_dir
+        self.tokenizer = transformers.AutoTokenizer.from_pretrained(model, **params)
+        self.config = transformers.AutoConfig.from_pretrained(model, **params)
 
-        param = {"config": self.config, "local_files_only": local_files_only, "use_auth_token": use_auth_token, "low_cpu_mem_usage": low_cpu_mem_usage}
+        params.update({"config": self.config, "low_cpu_mem_usage": low_cpu_mem_usage})
         if torch_dtype is not None:
-            param['torch_dtype'] = torch_dtype
+            params['torch_dtype'] = torch_dtype
         if device_map is not None:
-            param['device_map'] = device_map
-        self.model = transformers.AutoModelForCausalLM.from_pretrained(model, **param)
+            params['device_map'] = device_map
+        self.model = transformers.AutoModelForCausalLM.from_pretrained(model, **params)
 
         if self.tokenizer.pad_token is None:
             self.tokenizer.pad_token = "<<PAD>>"
